@@ -86,7 +86,7 @@ class DictMethodEntryHelper(object):
     def __init__(self, **kwargs):
         """
         Args:
-            **kwargs: (dict)  Placeholder for future key-value arguments
+            resourceProvider: (obj) instance of DictMethodResourceProvider()
 
         """
         #
